This is a extension of Python 3.10 or more later.

Caution
========== ========== ========== ========== ==========
This library is for Python 3.10 or more later,
so you can’t install it at Python 3.9 or more older.

License
========== ========== ========== ========== ==========
Copyright (C) 2021 Yile Wang

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.